This function generates a heatmap to visualize alpha diversity Hill numbers (q = 0, 1, 2) for a given dataset, faceted by one or two categorical variables (e.g., sample type or treatment). It supports palette customization, faceting, and statistical comparison.
ancombc_plot(
table,
metadata,
col_cond,
prv_cut = 0.1,
formula = NULL,
rand_formula = NULL
)A plot with the deferentially abundant taxonomic groups between two categories or groups of samples.
ancomb_plot(table = table,
conditions = conditions,
effect = 0.8,
formula = formula,
pvalue_BH = NULL)
#> Error in ancomb_plot(table = table, conditions = conditions, effect = 0.8, formula = formula, pvalue_BH = NULL): could not find function "ancomb_plot"